"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_customerinvoicesummary import (
    DtoCustomerInvoiceSummary,
    DtoCustomerInvoiceSummaryTypedDict,
)
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCustomerMultiCurrencyInvoiceSummaryTypedDict(TypedDict):
    customer_id: NotRequired[str]
    r"""customer_id is the unique identifier of the customer"""
    default_currency: NotRequired[str]
    r"""default_currency is the primary currency for this customer"""
    summaries: NotRequired[List[DtoCustomerInvoiceSummaryTypedDict]]
    r"""summaries contains the invoice summaries for each currency"""


class DtoCustomerMultiCurrencyInvoiceSummary(BaseModel):
    customer_id: Optional[str] = None
    r"""customer_id is the unique identifier of the customer"""

    default_currency: Optional[str] = None
    r"""default_currency is the primary currency for this customer"""

    summaries: Optional[List[DtoCustomerInvoiceSummary]] = None
    r"""summaries contains the invoice summaries for each currency"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["customer_id", "default_currency", "summaries"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_paymentresponse import DtoPaymentResponse, DtoPaymentResponseTypedDict
from .webhookeventname import WebhookEventName
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebhookDtoPaymentWebhookPayloadTypedDict(TypedDict):
    event_type: NotRequired[WebhookEventName]
    payment: NotRequired[DtoPaymentResponseTypedDict]


class WebhookDtoPaymentWebhookPayload(BaseModel):
    event_type: Optional[WebhookEventName] = None

    payment: Optional[DtoPaymentResponse] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event_type", "payment"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_cloneplanrequest import DtoClonePlanRequest, DtoClonePlanRequestTypedDict
from flexprice.types import BaseModel
from flexprice.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostPlansIDCloneRequestTypedDict(TypedDict):
    id: str
    r"""Source Plan ID"""
    body: DtoClonePlanRequestTypedDict
    r"""Clone configuration"""


class PostPlansIDCloneRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Source Plan ID"""

    body: Annotated[
        DtoClonePlanRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Clone configuration"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice.types import UnrecognizedStr
from typing import Literal, Union


ScheduledTaskInterval = Union[
    Literal[
        "15MIN",
        "30MIN",
        "custom",
        "hourly",
        "daily",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice.types import UnrecognizedStr
from typing import Literal, Union


WebhookEventName = Union[
    Literal[
        "invoice.create.drafted",
        "subscription.created",
        "subscription.draft.created",
        "subscription.activated",
        "subscription.updated",
        "subscription.paused",
        "subscription.cancelled",
        "subscription.resumed",
        "subscription.phase.created",
        "subscription.phase.updated",
        "subscription.phase.deleted",
        "feature.created",
        "feature.updated",
        "feature.deleted",
        "feature.wallet_balance.alert",
        "entitlement.created",
        "entitlement.updated",
        "entitlement.deleted",
        "wallet.created",
        "wallet.updated",
        "wallet.terminated",
        "wallet.transaction.created",
        "payment.created",
        "payment.updated",
        "payment.failed",
        "payment.success",
        "payment.pending",
        "customer.created",
        "customer.updated",
        "customer.deleted",
        "invoice.update.finalized",
        "invoice.update.payment",
        "invoice.update.voided",
        "invoice.update",
        "invoice.payment.overdue",
        "wallet.credit_balance.dropped",
        "wallet.credit_balance.recovered",
        "wallet.ongoing_balance.dropped",
        "wallet.ongoing_balance.recovered",
        "subscription.renewal.due",
        "invoice.communication.triggered",
        "credit_note.created",
        "credit_note.updated",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .alertsettings import AlertSettings, AlertSettingsTypedDict
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebhookDtoWalletAlertInfoTypedDict(TypedDict):
    alert_settings: NotRequired[AlertSettingsTypedDict]
    alert_type: NotRequired[str]
    credit_balance: NotRequired[float]
    current_balance: NotRequired[float]
    state: NotRequired[str]


class WebhookDtoWalletAlertInfo(BaseModel):
    alert_settings: Optional[AlertSettings] = None

    alert_type: Optional[str] = None

    credit_balance: Optional[float] = None

    current_balance: Optional[float] = None

    state: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "alert_settings",
                "alert_type",
                "credit_balance",
                "current_balance",
                "state",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
